You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ozone.apache.org by el...@apache.org on 2020/01/23 08:07:03 UTC

[hadoop-ozone] branch master updated: HDDS-2918. Increase timeout of safe-mode exit in acceptance tests

This is an automated email from the ASF dual-hosted git repository.

elek pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/hadoop-ozone.git


The following commit(s) were added to refs/heads/master by this push:
     new 803fa29  HDDS-2918. Increase timeout of safe-mode exit in acceptance tests
803fa29 is described below

commit 803fa292980230585c9092985a42645d4970ee20
Author: Doroszlai, Attila <ad...@apache.org>
AuthorDate: Thu Jan 23 09:06:42 2020 +0100

    HDDS-2918. Increase timeout of safe-mode exit in acceptance tests
    
    Closes #469
---
 hadoop-ozone/dist/src/main/compose/testlib.sh | 12 +++++-------
 1 file changed, 5 insertions(+), 7 deletions(-)

diff --git a/hadoop-ozone/dist/src/main/compose/testlib.sh b/hadoop-ozone/dist/src/main/compose/testlib.sh
index 9389d31..3f93c3a 100755
--- a/hadoop-ozone/dist/src/main/compose/testlib.sh
+++ b/hadoop-ozone/dist/src/main/compose/testlib.sh
@@ -32,7 +32,7 @@ create_results_dir() {
 }
 
 
 ## @description wait until safemode exit (or 90 seconds)
 ## @param the docker-compose file
 wait_for_safemode_exit(){
   local compose_file=$1
@@ -40,8 +40,8 @@ wait_for_safemode_exit(){
   #Reset the timer
   SECONDS=0
 
-  #Don't give it up until 90 seconds
-  while [[ $SECONDS -lt 90 ]]; do
+  #Don't give it up until 180 seconds
+  while [[ $SECONDS -lt 180 ]]; do
 
      #This line checks the safemode status in scm
      local command="ozone scmcli safemode status"
@@ -74,10 +74,8 @@ start_docker_env(){
   create_results_dir
   export OZONE_SAFEMODE_MIN_DATANODES="${datanode_count}"
   docker-compose -f "$COMPOSE_FILE" --no-ansi down
-  docker-compose -f "$COMPOSE_FILE" --no-ansi up -d --scale datanode="${datanode_count}" \
-    && wait_for_safemode_exit "$COMPOSE_FILE"
-
-  if [[ $? -gt 0 ]]; then
+  if ! { docker-compose -f "$COMPOSE_FILE" --no-ansi up -d --scale datanode="${datanode_count}" \
+      && wait_for_safemode_exit "$COMPOSE_FILE"; }; then
     OUTPUT_NAME="$COMPOSE_ENV_NAME"
     stop_docker_env
     return 1


---------------------------------------------------------------------
@@ -32,7 +32,7 @@ create_results_dir() {
 
 
-## @description wait until safemode exit (or 90 seconds)
+## @description wait until safemode exit (or 180 seconds)
 ## @param the docker-compose file
 wait_for_safemode_exit(){
To unsubscribe, e-mail: ozone-commits-unsubscribe@hadoop.apache.org
For additional commands, e-mail: ozone-commits-help@hadoop.apache.org